Feedforward Closedloop Learning: feedforward_closedloop_learning.FeedforwardClosedloopLearning Class Reference

Feedforward Closedloop Learning

Public Member Functions | Properties | List of all members
feedforward_closedloop_learning.FeedforwardClosedloopLearning Class Reference
Inheritance diagram for feedforward_closedloop_learning.FeedforwardClosedloopLearning:
[legend]
Collaboration diagram for feedforward_closedloop_learning.FeedforwardClosedloopLearning:
[legend]

## Public Member Functions
def | __init__ (self, "int" num_of_inputs, "int *" num_of_neurons_per_layer_array)
"void" | doStep (self, *args)
"double" | getOutput (self, "int" index)
"void" | setLearningRate (self, "double" learningRate)
"void" | setLearningRateDiscountFactor (self, "double" _learningRateDiscountFactor)
"void" | setDecay (self, "double" decay)
"void" | setMomentum (self, "double" momentum)
"void" | setActivationFunction (self, "Neuron::ActivationFunction" _activationFunction)
"void" | initWeights (self, *args)
"void" | seedRandom (self, "int" s)
"void" | setBias (self, "double" _bias)
"int" | getNumLayers (self)
"Layer *" | getLayer (self, "int" i)
"Layer *" | getOutputLayer (self)
"int" | getNumInputs (self)
"Layer **" | getLayers (self)
"bool" | saveModel (self, "char const *" name)
"bool" | loadModel (self, "char const *" name)

## Properties
| thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

## Detailed Description

    Proxy of C++ FeedforwardClosedloopLearning class.

## Constructor & Destructor Documentation

## ◆ __init__()

def feedforward_closedloop_learning.FeedforwardClosedloopLearning.__init__ | ( |  | self,
|  | "int" | num_of_inputs,
|  | "int *" | num_of_neurons_per_layer_array
| ) |  |

    __init__(FeedforwardClosedloopLearning self, int num_of_inputs, int * num_of_neurons_per_layer_array) -> FeedforwardClosedloopLearning

    Parameters
    ----------
    num_of_inputs: int
    num_of_neurons_per_layer_array: int *

## Member Function Documentation

## ◆ doStep()

"void" feedforward_closedloop_learning.FeedforwardClosedloopLearning.doStep | ( |  | self,
|  | * | args
| ) |  |

    doStep(FeedforwardClosedloopLearning self, double * input, double * error)

    Parameters
    ----------
    input: double *
    error: double *

    doStep(FeedforwardClosedloopLearning self, double * input, double * error)

    Parameters
    ----------
    input: double *
    error: double *

Reimplemented in feedforward_closedloop_learning.FeedforwardClosedloopLearningWithFilterbank.

## ◆ getLayer()

"Layer *" feedforward_closedloop_learning.FeedforwardClosedloopLearning.getLayer | ( |  | self,
|  | "int" | i
| ) |  |

    getLayer(FeedforwardClosedloopLearning self, int i) -> Layer

    Parameters
    ----------
    i: int

## ◆ getLayers()

"Layer **" feedforward_closedloop_learning.FeedforwardClosedloopLearning.getLayers | ( |  | self | ) |

    getLayers(FeedforwardClosedloopLearning self) -> Layer **

## ◆ getNumInputs()

"int" feedforward_closedloop_learning.FeedforwardClosedloopLearning.getNumInputs | ( |  | self | ) |

    getNumInputs(FeedforwardClosedloopLearning self) -> int

## ◆ getNumLayers()

"int" feedforward_closedloop_learning.FeedforwardClosedloopLearning.getNumLayers | ( |  | self | ) |

    getNumLayers(FeedforwardClosedloopLearning self) -> int

## ◆ getOutput()

"double" feedforward_closedloop_learning.FeedforwardClosedloopLearning.getOutput | ( |  | self,
|  | "int" | index
| ) |  |

    getOutput(FeedforwardClosedloopLearning self, int index) -> double

    Parameters
    ----------
    index: int

## ◆ getOutputLayer()

"Layer *" feedforward_closedloop_learning.FeedforwardClosedloopLearning.getOutputLayer | ( |  | self | ) |

    getOutputLayer(FeedforwardClosedloopLearning self) -> Layer

## ◆ initWeights()

"void" feedforward_closedloop_learning.FeedforwardClosedloopLearning.initWeights | ( |  | self,
|  | * | args
| ) |  |

    initWeights(FeedforwardClosedloopLearning self, double max=0.001, int initBias=1, Neuron::WeightInitMethod weightInitMethod=MAX_OUTPUT_RANDOM)

    Parameters
    ----------
    max: double
    initBias: int
    weightInitMethod: enum Neuron::WeightInitMethod

## ◆ loadModel()

"bool" feedforward_closedloop_learning.FeedforwardClosedloopLearning.loadModel | ( |  | self,
|  | "char const *" | name
| ) |  |

    loadModel(FeedforwardClosedloopLearning self, char const * name) -> bool

    Parameters
    ----------
    name: char const *

## ◆ saveModel()

"bool" feedforward_closedloop_learning.FeedforwardClosedloopLearning.saveModel | ( |  | self,
|  | "char const *" | name
| ) |  |

    saveModel(FeedforwardClosedloopLearning self, char const * name) -> bool

    Parameters
    ----------
    name: char const *

## ◆ seedRandom()

"void" feedforward_closedloop_learning.FeedforwardClosedloopLearning.seedRandom | ( |  | self,
|  | "int" | s
| ) |  |

    seedRandom(FeedforwardClosedloopLearning self, int s)

    Parameters
    ----------
    s: int

## ◆ setActivationFunction()

"void" feedforward_closedloop_learning.FeedforwardClosedloopLearning.setActivationFunction | ( |  | self,
|  | "Neuron::ActivationFunction" | _activationFunction
| ) |  |

    setActivationFunction(FeedforwardClosedloopLearning self, Neuron::ActivationFunction _activationFunction)

    Parameters
    ----------
    _activationFunction: enum Neuron::ActivationFunction

## ◆ setBias()

"void" feedforward_closedloop_learning.FeedforwardClosedloopLearning.setBias | ( |  | self,
|  | "double" | _bias
| ) |  |

    setBias(FeedforwardClosedloopLearning self, double _bias)

    Parameters
    ----------
    _bias: double

## ◆ setDecay()

"void" feedforward_closedloop_learning.FeedforwardClosedloopLearning.setDecay | ( |  | self,
|  | "double" | decay
| ) |  |

    setDecay(FeedforwardClosedloopLearning self, double decay)

    Parameters
    ----------
    decay: double

## ◆ setLearningRate()

"void" feedforward_closedloop_learning.FeedforwardClosedloopLearning.setLearningRate | ( |  | self,
|  | "double" | learningRate
| ) |  |

    setLearningRate(FeedforwardClosedloopLearning self, double learningRate)

    Parameters
    ----------
    learningRate: double

## ◆ setLearningRateDiscountFactor()

"void" feedforward_closedloop_learning.FeedforwardClosedloopLearning.setLearningRateDiscountFactor | ( |  | self,
|  | "double" | _learningRateDiscountFactor
| ) |  |

    setLearningRateDiscountFactor(FeedforwardClosedloopLearning self, double _learningRateDiscountFactor)

    Parameters
    ----------
    _learningRateDiscountFactor: double

## ◆ setMomentum()

"void" feedforward_closedloop_learning.FeedforwardClosedloopLearning.setMomentum | ( |  | self,
|  | "double" | momentum
| ) |  |

    setMomentum(FeedforwardClosedloopLearning self, double momentum)

    Parameters
    ----------
    momentum: double

The documentation for this class was generated from the following file:

- feedforward_closedloop_learning.py